@@ -1,5 +1,5 @@
 //! Rust FFI bindings to the [FTDI D2XX drivers](https://www.ftdichip.com/Drivers/D2XX.htm).
-#![doc(html_root_url = "https://docs.rs/libftd2xx-ffi/0.8.3")]
+#![doc(html_root_url = "https://docs.rs/libftd2xx-ffi/0.8.4")]
 #![allow(non_upper_case_globals)]
 #![allow(non_camel_case_types)]
 #![allow(non_snake_case)]
@@ -23,6 +23,8 @@ cfg_if::cfg_if! {
         include!("bindings_linux_armv8.rs");
     } else if #[cfg(all(target_os = "macos", target_arch = "x86_64"))] {
         include!("bindings_macos_x64.rs");
+    } else if #[cfg(all(target_os = "macos", target_arch = "aarch64"))] {
+        include!("bindings_macos_aarch64.rs");
     } else {
         std::compile_error!("pre-generated bindings are not avaliable for your target");
     }
